@@ -371,5 +371,5 @@ PARTICULAR PURPOSE.  See the GNU Library General Public License for more
 details.
 
 You should have received a copy of the GNU Library General Public License along
-with this library; if not, write to the Free Software Foundation, Inc., 59
-Temple Place - Suite 330, Boston, MA  02111-1307  USA.
+with this library; if not, write to the Free Software Foundation, Inc., 
+51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
